Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(285)

Unified Diff: chrome/browser/sync/profile_sync_service.h

Issue 2880001: HTML sync setup UI. (Closed) Base URL: http://src.chromium.org/git/chromium.git
Patch Set: Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/sync/glue/sync_backend_host.cc ('k') | chrome/browser/sync/profile_sync_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync/profile_sync_service.h
diff --git a/chrome/browser/sync/profile_sync_service.h b/chrome/browser/sync/profile_sync_service.h
index 929d8bd81c1ab1c4386c0c75c31760f7c41f0189..ece018a14cec709bef45bcc46bf7978698144740 100644
--- a/chrome/browser/sync/profile_sync_service.h
+++ b/chrome/browser/sync/profile_sync_service.h
@@ -112,7 +112,8 @@ class ProfileSyncService : public browser_sync::SyncFrontend,
CANCEL_FROM_SIGNON_WITHOUT_AUTH = 10, // Cancelled before submitting
// username and password.
CANCEL_DURING_SIGNON = 11, // Cancelled after auth.
-
+ CANCEL_FROM_CHOOSE_DATA_TYPES = 12, // Cancelled before choosing data
+ // types and clicking OK.
// Events resulting in the stoppage of sync service.
STOP_FROM_OPTIONS = 20, // Sync was stopped from Wrench->Options.
@@ -169,11 +170,11 @@ class ProfileSyncService : public browser_sync::SyncFrontend,
// Called when a user chooses which data types to sync as part of the sync
// setup wizard. |sync_everything| represents whether they chose the
// "keep everything synced" option; if true, data_types will be ignored and
// all data types will be synced. |sync_everything| means "sync all current
// and future data types."
virtual void OnUserChoseDatatypes(bool sync_everything,
- const syncable::ModelTypeSet& data_types);
+ const syncable::ModelTypeSet& chosen_types);
// Called when a user cancels any setup dialog (login, etc).
virtual void OnUserCancelledDialog();
@@ -201,6 +202,8 @@ class ProfileSyncService : public browser_sync::SyncFrontend,
}
void ShowLoginDialog();
+ void ShowChooseDataTypes();
+
// Pretty-printed strings for a given StatusSummary.
static std::wstring BuildSyncStatusSummaryText(
const browser_sync::SyncBackendHost::StatusSummary& summary);
@@ -169,11 +170,11 @@ class ProfileSyncService : public browser_sync::SyncFrontend,
// Called when a user chooses which data types to sync as part of the sync
// setup wizard. |sync_everything| represents whether they chose the
- // "keep everything synced" option; if true, data_types will be ignored and
- // all data types will be synced. |sync_everything| means "sync all current
- // and future data types."
+ // "keep everything synced" option; if true, |chosen_types| will be ignored
+ // and all data types will be synced. |sync_everything| means "sync all
+ // current and future data types."
virtual void OnUserChoseDatatypes(bool sync_everything,
« no previous file with comments | « chrome/browser/sync/glue/sync_backend_host.cc ('k') | chrome/browser/sync/profile_sync_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698